@@ -1,4 +1,4 @@
-from dataclasses import dataclass, field
+from dataclasses import dataclass, field, asdict
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
@@ -10,9 +10,6 @@ class IJWT(ABC):
     def getToken(self):
         pass
     @abstractmethod
-    def updateToken(self):
-        pass
-    @abstractmethod
     def isExpired(self):
         pass
     @abstractmethod
